@@ -6,13 +6,13 @@ from reamber.algorithms.generate.sv.SvPkg import SvPkg
 from reamber.algorithms.generate.sv.SvSequence import SvSequence
 
 
-def svFuncSequencer(funcs: List[Union[float, Callable[[float], float], None]],
-                    offsets: Union[List[float], float, None] = None,
-                    repeats: int = 1,
-                    repeatGap: float = 0,
-                    startX: float = 0,
-                    endX: float = 1
-                    ):
+def sv_func_sequencer(funcs: List[Union[float, Callable[[float], float], None]],
+                      offsets: Union[List[float], float, None] = None,
+                      repeats: int = 1,
+                      repeat_gap: float = 0,
+                      start_x: float = 0,
+                      end_x: float = 1
+                      ):
     """ Sets up a sequence using functions.
 
     :param funcs: Funcs to generate values. \
@@ -25,9 +25,9 @@ def svFuncSequencer(funcs: List[Union[float, Callable[[float], float], None]],
         If None, all funcs are assumed to be separated by 1 ms. Starting from 0.
     :param repeats: The amount of repeats. This affects the increment of the X argument passed to the Callables. \
         If 0, only endX will be used.
-    :param repeatGap: The gap between the repeats.
-    :param startX: The starting X.
-    :param endX: The ending X.
+    :param repeat_gap: The gap between the repeats.
+    :param start_x: The starting X.
+    :param end_x: The ending X.
     """
 
     length = len(funcs)
@@ -41,16 +41,16 @@ def svFuncSequencer(funcs: List[Union[float, Callable[[float], float], None]],
     seq = SvSequence()
 
     for i, (offset, func) in enumerate(zip(offsets, funcs)):
-        if isinstance(func, Callable): seq.appendInit([(offset, 0)])
-        elif isinstance(func, (float, int)): seq.appendInit([(offset, func)])
+        if isinstance(func, Callable): seq.append_init([(offset, 0)])
+        elif isinstance(func, (float, int)): seq.append_init([(offset, func)])
         elif func is None: pass
 
-    pkg = SvPkg.repeat(seq=seq, times=repeats, gap=repeatGap)
+    pkg = SvPkg.repeat(seq=seq, times=repeats, gap=repeat_gap)
 
     nones = 0
     for funcI, func in enumerate(funcs):
         if func is None: nones += 1
         if isinstance(func, Callable):
-            pkg.applyNth(func, funcI - nones, startX, endX)
+            pkg.apply_nth(func, funcI - nones, start_x, end_x)
 
     return pkg
