@@ -18,7 +18,7 @@ class OsuBpmList(BpmList[OsuBpm]):
 
         :param strings: A List of strings to loop through OsuHit.read
         """
-        return OsuBpmList(pd.DataFrame([OsuBpm.read_string(s, as_dict=True) for s in strings]))
+        return OsuBpmList(pd.DataFrame([OsuBpm.read_string(s, as_dict=True) for s in strings]) if strings else [])
 
     def write(self) -> List[str]:
         return [h.write_string() for h in self]
