@@ -17,9 +17,7 @@ class OsuSvList(TimedList[OsuSv]):
 
         :param strings: A List of strings to loop through OsuHit.read
         """
-        return OsuSvList(
-            pd.DataFrame([OsuSv.read_string(s, as_dict=True) for s in strings])
-        )
+        return OsuSvList(pd.DataFrame([OsuSv.read_string(s, as_dict=True) for s in strings]) if strings else [])
 
     def write(self) -> List[str]:
         return [h.write_string() for h in self]
