@@ -9,7 +9,8 @@ class TestCopyTo(unittest.TestCase):
     def testCopy(self):
         # Test Copy
         seq = SvSequence([SvObj(0, 1.0), SvObj(100, 2.0)])
-        seqCopy = SvPkg.copyTo(seq=seq,offsets=[100, 200, 300]).combine(combineMethod=SvPkg.CombineMethod.DROP_BY_POINT)
+        seqCopy = SvPkg.copy_to(seq=seq, offsets=[100, 200, 300]).combine(
+            combine_method=SvPkg.CombineMethod.DROP_BY_POINT)
         self.assertEqual(len(seqCopy), 4)
 
 
